@@ -56,7 +56,7 @@
       http://www.networkupstools.org/nut-qa.html
 '''
 
-# QRT-Packages: netcat-openbsd python
+# QRT-Packages: netcat-openbsd psmisc python
 # QRT-Alternates: nut-server nut
 # QRT-Alternates: nut-client nut
 # nut-dev is needed for the dummy driver on hardy
@@ -69,13 +69,19 @@ import unittest, subprocess, sys, os, time
 import tempfile
 import testlib
 
+# The behaviour of the upstream systemd services has changed breaking the
+# existing tests. This is a quick fix for the tests so they use the sysv
+# initscript instead of the systemd services.
+# The tests should probably be adjusted in the future.
+os.environ['SYSTEMCTL_SKIP_REDIRECT'] = '1'
+
 use_private = True
 try:
     from private.qrt.nut import PrivateNutTest
 except ImportError:
     class PrivateNutTest(object):
         '''Empty class'''
-    print >>sys.stdout, "Skipping private tests"
+    print("Skipping private tests")
 
 
 class NutTestCommon(testlib.TestlibCase):
@@ -161,7 +167,7 @@ FINALDELAY 0
 
         testlib.create_fill(self.notifyscript, '''
 #! /bin/bash
-echo "$*" > ''' + self.notifylog + '\n', mode=0755)
+echo "$*" > ''' + self.notifylog + '\n', mode=0o755)
 
         # dummy-ups absolutely needs a data file, even if empty
         testlib.config_replace('/etc/nut/dummy.dev', '''
@@ -196,7 +202,7 @@ UPSMON_OPTIONS=""
     def _tearDown(self):
         '''Clean up after each test_* function'''
         self._stop()
-        time.sleep(2)
+        time.sleep(20)
         os.unlink('/etc/nut/ups.conf')
         os.unlink('/etc/nut/upsd.conf')
         os.unlink('/etc/nut/upsd.users')
@@ -230,27 +236,27 @@ UPSMON_OPTIONS=""
         rc, report = testlib.cmd([self.initscript, 'start'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
-        time.sleep(2)
+        self.assertEqual(expected, rc, result + report)
+        time.sleep(100)
 
     def _stop(self):
         '''Stop NUT'''
         rc, report = testlib.cmd([self.initscript, 'stop'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _reload(self):
         '''Reload NUT'''
         rc, report = testlib.cmd([self.initscript, 'force-reload'])
         expected = 0
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _restart(self):
         '''Restart NUT'''
         self._stop()
-        time.sleep(2)
+        time.sleep(20)
         self._start()
 
     def _status(self):
@@ -261,7 +267,7 @@ UPSMON_OPTIONS=""
             self._skipped("init script does not support status command")
             expected = 1
         result = 'Got exit code %d, expected %d\n' % (rc, expected)
-        self.assertEquals(expected, rc, result + report)
+        self.assertEqual(expected, rc, result + report)
 
     def _testDaemons(self, daemons):
         '''Daemons running'''
@@ -300,6 +306,7 @@ class BasicTest(NutTestCommon, PrivateNutTest):
         '''Test daemons using "service status"'''
         self._status()
 
+    @unittest.skip("Skip flaky test (especially on armel). See #1064670 for further reference.")
     def test_daemons_pid(self):
         '''Test daemons using PID files'''
         # upsmon does not work because ups-client is still missing
@@ -332,11 +339,12 @@ class BasicTest(NutTestCommon, PrivateNutTest):
     # Result == Main ; dummy-dev1 ; $hostname
     #    self.assertTrue('dummy-dev1' in report, 'dummy-dev1 should be present in device(s) listing: ' + report)
 
+    @unittest.skip("Skip flaky test. See #1023530 and LP: #1998481 for further reference.")
     def test_upsrw(self):
         '''Test upsrw'''
         # Set ups.status to OB (On Battery)...
         self._nut_setvar('ups.model', 'Test')
-        time.sleep(2)
+        time.sleep(20)
         # and check the result on the client side
         rc, report = testlib.cmd(['/bin/upsc', 'dummy-dev1@localhost', 'ups.model'])
         self.assertTrue('Test' in report, 'UPS Model: ' + report + 'should be Test')
@@ -345,11 +353,12 @@ class BasicTest(NutTestCommon, PrivateNutTest):
     #def test_upscmd(self):
     #    '''Test upscmd'''
 
+    @unittest.skip("Skip flaky test. See #1023530 and LP: #1998481 for further reference.")
     def test_upsmon_notif(self):
         '''Test upsmon notifications'''
         # Set ups.status to OB (On Battery)...
         self._nut_setvar('ups.status', 'OB')
-        time.sleep(1)
+        time.sleep(10)
         # and check the result on the client side
         rc, report = testlib.cmd(['/bin/upsc', 'dummy-dev1@localhost', 'ups.status'])
         self.assertTrue('OB' in report, 'UPS Status: ' + report + 'should be OB')
@@ -379,7 +388,7 @@ printf '\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\n' | nc -q 1 127.0.0.1
 sleep 1
 dd if=/dev/urandom count=64 | nc -q 1 127.0.0.1 3493
 '''
-        testlib.create_fill(script, contents, mode=0755)
+        testlib.create_fill(script, contents, mode=0o755)
         rc, report = testlib.cmd([script])
 
         # It should not have crashed. Let's see if it did
@@ -392,7 +401,7 @@ dd if=/dev/urandom count=64 | nc -q 1 127.0.0.1 3493
         pidfile = os.path.join(self.rundir, 'upsd.pid')
         timeout = 50
         while timeout > 0 and os.path.exists(pidfile):
-            time.sleep(0.1)
+            time.sleep(1)
             timeout -= 1
         self.assertFalse(os.path.exists(pidfile), "Found %s" % pidfile)
         self.assertFalse(testlib.check_pidfile('upsd', pidfile), 'upsd is hung')
@@ -414,9 +423,9 @@ if __name__ == '__main__':
     #    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(MyPrivateTest))
 
     else:
-        print '''Usage:
+        print('''Usage:
   test-nut.py [-v]             basic tests
-'''
+''')
         sys.exit(1)
     rc = unittest.TextTestRunner(verbosity=2).run(suite)
     if not rc.wasSuccessful():
